package Cdk::Template;

@ISA = qw (Cdk);

#
# This creates a new Template object.
#
sub new {
    my $type   = shift;
    my %params = @_;
    my $self   = {};
    my $name   = "${type}::new";

    # Retain the type of the object.
    $self->{'Type'} = $type;

    # Set up the parameters passed in.
    my $plate   = Cdk::checkReq( $name, "Plate",   $params{'Plate'} );
    my $overlay = Cdk::checkReq( $name, "Overlay", $params{'Overlay'} );
    my $title  = Cdk::checkDef( $name, "Title",  $params{'Title'},  "" );
    my $label  = Cdk::checkDef( $name, "Label",  $params{'Label'},  "" );
    my $xpos   = Cdk::checkDef( $name, "Xpos",   $params{'Xpos'},   "CENTER" );
    my $ypos   = Cdk::checkDef( $name, "Ypos",   $params{'Ypos'},   "CENTER" );
    my $box    = Cdk::checkDef( $name, "Box",    $params{'Box'},    "TRUE" );
    my $shadow = Cdk::checkDef( $name, "Shadow", $params{'Shadow'}, "FALSE" );

    # Create the thing.
    $self->{'Me'} =
      Cdk::Template::New( $title, $label, $plate, $overlay, $xpos, $ypos, $box,
        $shadow );
    bless $self;
}

#
# This activates the object
#
sub activate {
    my $self   = shift;
    my %params = @_;
    my $name   = "$self->{'Type'}::activate";

    # Activate the object...
    if ( defined $params{'Input'} ) {
        $self->{'Info'} =
          Cdk::Template::Activate( $self->{'Me'}, $params{'Input'} );
    }
    else {
        $self->{'Info'} = Cdk::Template::Activate( $self->{'Me'} );
    }
    return ( $self->{'Info'} );
}

#
# This injects a character into the widget.
#
sub inject {
    my $self   = shift;
    my %params = @_;
    my $name   = "$self->{'Type'}::inject";

    # Set the values.
    my $character = Cdk::checkReq( $name, "Input", $params{'Input'} );

    return ( Cdk::Template::Inject( $self->{'Me'}, $character ) );
}

#
# This sets several parameters of the widget.
#
sub set {
    my $self   = shift;
    my %params = @_;
    my $name   = "$self->{'Type'}::set";

    #
    # Check the parameters sent in.
    #
    if ( defined $params{'Value'} ) {
        Cdk::Template::SetValue( $self->{'Me'}, $params{'Value'} );
    }
    if ( defined $params{'Min'} ) {
        Cdk::Template::SetMin( $self->{'Me'}, $params{'Min'} );
    }
    if ( defined $params{'ULChar'} ) {
        Cdk::Template::SetULChar( $self->{'Me'}, $params{'ULChar'} );
    }
    if ( defined $params{'URChar'} ) {
        Cdk::Template::SetURChar( $self->{'Me'}, $params{'URChar'} );
    }
    if ( defined $params{'LLChar'} ) {
        Cdk::Template::SetLLChar( $self->{'Me'}, $params{'LLChar'} );
    }
    if ( defined $params{'LRChar'} ) {
        Cdk::Template::SetLRChar( $self->{'Me'}, $params{'LRChar'} );
    }
    if ( defined $params{'VChar'} ) {
        Cdk::Template::SetVerticalChar( $self->{'Me'}, $params{'VChar'} );
    }
    if ( defined $params{'HChar'} ) {
        Cdk::Template::SetHorizontalChar( $self->{'Me'}, $params{'HChar'} );
    }
    if ( defined $params{'BoxAttribute'} ) {
        Cdk::Template::SetBoxAttribute( $self->{'Me'},
            $params{'BoxAttribute'} );
    }
    if ( defined $params{'BGColor'} ) {
        Cdk::Template::SetBackgroundColor( $self->{'Me'}, $params{'BGColor'} );
    }
    if ( defined $params{'Box'} ) {
        Cdk::Template::SetBox( $self->{'Me'}, $params{'Box'} );
    }
}

#
# This function allows the user to get the current value from the widget.
#
sub get {
    my $self = shift;
    return ( Cdk::Template::Get( $self->{'Me'} ) );
}

#
# This binds a given key to a given function.
#
sub bind {
    my $self   = shift;
    my %params = @_;
    my $name   = "$self->{'Type'}::bind";

    # Set the values.
    my $key      = Cdk::checkReq( $name, "Key",      $params{'Key'} );
    my $function = Cdk::checkReq( $name, "Function", $params{'Function'} );
    Cdk::Template::Bind( $self->{'Me'}, $key, $params{'Function'} );
}

#
# This allows us to set a pre-process function.
#
sub preProcess {
    my $self   = shift;
    my %params = @_;
    my $name   = "$self->{'Type'}::preProcess";

    # Set the values.
    my $function = Cdk::checkReq( $name, "Function", $params{'Function'} );
    Cdk::Template::PreProcess( $self->{'Me'}, $params{'Function'} );
}

#
# This allows us to set a post-process function.
#
sub postProcess {
    my $self   = shift;
    my %params = @_;
    my $name   = "$self->{'Type'}::postProcess";

    # Set the values.
    my $function = Cdk::checkReq( $name, "Function", $params{'Function'} );
    Cdk::Template::PostProcess( $self->{'Me'}, $params{'Function'} );
}

#
# This draws the object.
#
sub draw {
    my $self   = shift;
    my %params = @_;
    my $name   = "$self->{'Type'}::draw";

    # Set the values.
    my $box = Cdk::checkDef( $name, "Box", $params{'Box'}, "TRUE" );

    # Draw the object.
    Cdk::Template::Draw( $self->{'Me'}, $box );
}

#
# This erases the object.
#
sub erase {
    my $self = shift;
    Cdk::Template::Erase( $self->{'Me'} );
}

#
# This cleans the template info field.
#
sub clean {
    my $self = shift;
    Cdk::Template::Clean( $self->{'Me'} );
}

#
# This mixes the results with the overlay
#
sub mix {
    my $self = shift;
    Cdk::Template::Mix( $self->{'Me'} );
}

#
# This function raises the object.
#
sub raise {
    my $self = shift;
    Cdk::Template::Raise( $self->{'Me'} );
}

#
# This function lowers the object.
#
sub lower {
    my $self = shift;
    Cdk::Template::Lower( $self->{'Me'} );
}

#
# This function registers the object.
#
sub register {
    my $self = shift;
    Cdk::Template::Register( $self->{'Me'} );
}

#
# This function unregisters the object.
#
sub unregister {
    my $self = shift;
    Cdk::Template::Unregister( $self->{'Me'} );
}

#
# This function returns the pointer to the window.
#
sub getwin {
    my $self = shift;
    Cdk::Template::GetWindow( $self->{'Me'} );
}

1;
